
#ifndef __e_data_server_marshal_MARSHAL_H__
#define __e_data_server_marshal_MARSHAL_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* NONE:NONE (./e-data-server-marshal.list:1) */
#define e_data_server_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
#define e_data_server_marshal_NONE__NONE	e_data_server_marshal_VOID__VOID

/* NONE:OBJECT (./e-data-server-marshal.list:2) */
#define e_data_server_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
#define e_data_server_marshal_NONE__OBJECT	e_data_server_marshal_VOID__OBJECT

/* NONE:STRING (./e-data-server-marshal.list:3) */
#define e_data_server_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
#define e_data_server_marshal_NONE__STRING	e_data_server_marshal_VOID__STRING

G_END_DECLS

#endif /* __e_data_server_marshal_MARSHAL_H__ */

